###################################################
### chunk number 1: 
###################################################
## Sets display options
options(width = 75, digits = 2, scipen = 5)

library(portfolioSim)


###################################################
### chunk number 2: 
###################################################
data.frame(id = c("A", "B", "C"), shares = c(10, 20, -10))


###################################################
### chunk number 3: 
###################################################
data.frame(id = c("B","C","D","E"), side=c("S","C","B","X"), shares=c(20,5,10,20))


###################################################
### chunk number 4: 
###################################################
data.frame(id=c("A","C","D","E"), shares=c(10,-5,10,-20))


###################################################
### chunk number 5: 
###################################################

library(portfolioSim)

sdi <- new("sdiDf", data = data.frame(period = c(rep(1, times=4),
                                                 rep(2, times=4),
                                                 rep(3, times=4),
                                                 rep(4, times=4)),
                                      id = rep(c("A","B","C","D"), times=4)))
sdi@data$id <- as.character(sdi@data$id)
sdi@data$ret <- 0
sdi@data$start.price <- 10
sdi@data$end.price <- 10
sdi@data$volume <- 100
sdi@data$universe <- TRUE
sdi@data$universe[15] <- FALSE

trades.1 <- new("trades", trades = data.frame(id = c("A","B"),
                                              side = c("B","X"),
                                              shares = c(10,10)))
trades.2 <- new("trades", trades = data.frame(id = c("B","C","A","A"),
                                              side = c("C","B","X","S"),
                                              shares = c(5,5,10,10)))
trades.3 <- new("trades", trades = data.frame(id = c("B","D"),
                                              side = c("C","B"),
                                              shares = c(5,20)))
trades.4 <- new("trades", trades = data.frame(id = c("D"),
                                              side = c("B"),
                                              shares = c(5)))

sti <- new("stiPresetTrades", periods = c(1,2,3,4),
                              sim.trades = list(trades.1, trades.2,
                                                trades.3, trades.4))

periods <- data.frame(period = c(1,2,3,4), start = c(1,2,3,4), end = c(1,2,3,4))

ps <- new("portfolioSim", periods = periods, data.interface = sdi,
          trades.interface = sti, out.loc = "out_dir_1",
          out.type = c("portfolio","trades","basic"))

sim.portfolios <- runSim(ps, verbose = FALSE)



###################################################
### chunk number 6: 
###################################################
getSimData(ps@data.interface, period = 1, verbose = FALSE)@data


###################################################
### chunk number 7: 
###################################################
getSimTrades(ps@trades.interface, period = 1, holdings = new("portfolio"),
             sim.data = new("simData"), verbose = FALSE)@trades@trades


###################################################
### chunk number 8: 
###################################################
sim.portfolios@data[[1]]@end.data@holdings@shares


###################################################
### chunk number 9: 
###################################################
getSimTrades(ps@trades.interface, period = 2, holdings = new("portfolio"),
             sim.data = new("simData"), verbose = FALSE)@trades@trades


###################################################
### chunk number 10: 
###################################################
sim.portfolios@data[[2]]@end.data@holdings@shares


###################################################
### chunk number 11: 
###################################################
getSimTrades(ps@trades.interface, period = 3, holdings = new("portfolio"),
             sim.data = new("simData"), verbose = FALSE)@trades@trades


###################################################
### chunk number 12: 
###################################################
sim.portfolios@data[[3]]@end.data@holdings@shares


###################################################
### chunk number 13: 
###################################################
getSimTrades(ps@trades.interface, period = 4, holdings = new("portfolio"),
             sim.data = new("simData"), verbose = FALSE)@trades@trades


###################################################
### chunk number 14: 
###################################################
getSimData(ps@data.interface, period = 4, verbose = FALSE)@data


###################################################
### chunk number 15: 
###################################################
sim.portfolios@data[[4]]@start.data@holdings@shares


###################################################
### chunk number 16: 
###################################################
sim.portfolios@data[[4]]@end.data@holdings@shares


###################################################
### chunk number 17: 
###################################################
data.frame(period = 1:4,
start = as.POSIXct(c("2006-01-01 09:30", "2006-04-01 09:30", "2006-07-01 09:30", "2006-10-01 09:30")),
end = as.POSIXct(c("2006-03-31 16:00", "2006-06-30 16:00", "2006-09-30 16:00", "2006-12-31 16:00")))


###################################################
### chunk number 18: 
###################################################
data(starmine.sim)
names(starmine.sim)


###################################################
### chunk number 19: 
###################################################
periods <- data.frame(period = sort(starmine.sim$date[!duplicated(starmine.sim$date)]))
## periods <- data.frame(period = unique(starmine.sim$date))
periods$start <- periods$period
periods$end <- c(periods$start[-1], as.Date("1995-12-31"))

periods


###################################################
### chunk number 20: 
###################################################
starmine.sim$period <- starmine.sim$date


###################################################
### chunk number 21: 
###################################################
starmine.sim$start.price <- starmine.sim$prior.close.usd
starmine.sim$end.price <- starmine.sim$price.usd


###################################################
### chunk number 22: 
###################################################
starmine.sim$ret <- starmine.sim$ret.1m


###################################################
### chunk number 23: 
###################################################
starmine.sim$universe <- TRUE


###################################################
### chunk number 24: 
###################################################
data.interface <- new("sdiDf", data = starmine.sim)


###################################################
### chunk number 25: 
###################################################
trades.interface <- new("stiFromSignal", in.var = "smi",
size = "decile", equity = 1000000, rebal.on = periods$period)


###################################################
### chunk number 26: 
###################################################
ps <- new("portfolioSim", periods = periods, freq = 12,
data.interface = data.interface, trades.interface = trades.interface,
fill.volume.pct = Inf, out.loc = "out_dir_2", out.type = "lean")


###################################################
### chunk number 27: 
###################################################
result <- runSim(ps, verbose = FALSE)


###################################################
### chunk number 28: 
###################################################
summary(result)


###################################################
### chunk number 29: 
###################################################
ps@out.type <- "detail"
result <- runSim(ps, verbose = FALSE)


###################################################
### chunk number 30: 
###################################################
summary(result)


###################################################
### chunk number 31: 
###################################################
result <- loadIn(new("simResult"), in.loc = "out_dir_2")


###################################################
### chunk number 32: 
###################################################
unlink("out_dir_1", recursive = TRUE)
unlink("out_dir_2", recursive = TRUE)


